@@ -25,8 +25,15 @@ def insert_batch(
     df = pd.DataFrame(dbLlist)
     df = df.replace({np.nan: None})
     tuples = [tuple(x) for x in df.to_numpy()]
-    cols = ",".join(list(df.columns))
-    query_placeholders = ", ".join(["%s"] * len(list(df.columns)))
+
+    list_cols = list(df.columns)
+
+    for index, item in enumerate(list_cols):
+        if "/" in item:
+            list_cols[index] = f'"{list_cols[index].lower()}"'
+
+    cols = ",".join(list_cols)
+    query_placeholders = ", ".join(["%s"] * len(list_cols))
 
     query = "INSERT INTO %s(%s) VALUES(%s) %s" % (
         table,
